.. include:: ../../README.rst

.. figure:: _static/parceqt.png

   A screenshot of the debugger included with *parceqt*

This manual documents `parce` version |release|.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   overview.rst
   gettingstarted.rst
   deflanguage.rst
   treestructure.rst
   building.rst
   doc.rst
   transforming.rst

   langs.rst
   stdactions.rst
   modoverview.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :doc:`changelog`
* :doc:`license`
